Falcon HATEOAS
==============

Early prototype of HATOAS REST API framework based on Falcon web framework and
SQLAlchemy.

Purpose of this project is to make creating simple, yet robust, REST API supporting HATEOAS quick and easy. You should only provide your own SQLAlchemy models and just quickly declare some URL<->RESOURCE<->MODEL mapping.
